@@ -47,11 +47,11 @@ sub import {
 }
 
 
-our $VERSION = '0.0177';    # VERSION
+our $VERSION = '0.0178';    # VERSION
 
 1;
 
-# ABSTRACT: Evo - the posmodern development framework
+# ABSTRACT: Evo - the next generation component-oriented development framework
 
 __END__
 
@@ -61,11 +61,11 @@ __END__
 
 =head1 NAME
 
-Evo - Evo - the posmodern development framework
+Evo - Evo - the next generation component-oriented development framework
 
 =head1 VERSION
 
-version 0.0177
+version 0.0178
 
 =head1 DESCRIPTION
 
@@ -81,13 +81,13 @@ Rewritten sexy L<Evo::Export>
 Post modern component oriented programming L<Evo::Comp> instead of OO
 
 =item *
-Fast Event-Loop L<Evo::Loop> with unique feature zones (Not ready)
+(no docs yet) Fast Event-Loop L<Evo::Loop> with unique feature zones (Not ready)
 
 =item *
-Fast non recursive L<Evo::Promises>, 100% Promises/Spec A compatible
+(no docs yet) Fast non recursive L<Evo::Promises>, 100% Promises/Spec A compatible
 
 =item *
-Interesting L<Evo::Realm> design pattern, which is as handy as "Singleton" but without Sintleton's flaws.
+(no docs yet) Interesting L<Evo::Realm> design pattern, which is as handy as "Singleton" but without Sintleton's flaws.
 It makes real thing that are considered impossible in other languages. For example, testing EventLoop timers without patching, separating flows for one loop and so on.
 (ready but experimental and not documented)
 
