@@ -16,7 +16,7 @@ Evo::Comp
 
 =head1 VERSION
 
-version 0.0177
+version 0.0178
 
 =head1 DESCRIPTION
 
@@ -36,9 +36,11 @@ The most problems with Moose like modules is with initialization. Let's take a l
   my $obj = My::Moose->new(fo => 3);
   print $obj->foo;
 
-As you can see, we passed C<fo> instead of C<foo>, and Moose silently ignored it.  You should write a huge amout of extra tests to pervent such errors. So I decided to write all the stuff and name it component oriented programming.
+As you can see, we passed C<fo> instead of C<foo>, and Moose silently ignored it. You should write a huge amout of extra tests to pervent such errors.
 
-More explanation will be written later
+Also traditional OO programming suffers the fragile base class problems (use Google). To solve it, component oriented C<Evo::Comp> introduces flexible component roles L<Evo::Comp::Role>. 
+
+So I decided to write all the stuff and name it component oriented programming. More explanation will be written later
 
 =head1 SYNOPSYS
 
@@ -169,97 +171,9 @@ You can also return C<(0, "CustomError")> to provide more expressive explanation
   $foo->big(9);    # will die
   my $bar = My::Foo::new(big => 9);    # will die
 
-=head2 Code reuse (Roles)
+=head2 Code reuse
 
-!!! Below C<-Loaded> is only needed to copy-paste examples into one file and run it. In the real life code, where every role has separate file, it's unneccessary.
-
-OO is considered an anti-pattern because it's hard to change and reuse such code, and every refactoring makes OO applications low-tested or extra-tested. Component oriented programming doesn't have such weakness. It uses roles (like Moose's roles), or so called "mixins".
-
-Because of that, Components are faster, simpler, and more reusable
-Also Roles can protect you from method and attributes clashing, because all methods and attributes will be installed into one file
-
-I'll write an article about this late (maybe)
-
-Here is a breaf overview
-
-  package main;
-  use Evo;
-
-  {
-
-    package Person::Human;
-    use Evo '-Comp::Role *; -Loaded';
-    has 'name';
-    sub upper_name : Role { uc shift->name }
-
-    package Person;
-    use Evo '-Comp *';
-
-    with ':Human';    # same as "Person::Human";
-    sub intro { say "My name is ", shift->upper_name }
-
-  };
-
-  my $alex = Person::new(name => 'alex');
-  $alex->intro;
-
-As you can see, role shares attributes and methods.
-To share method, add C<Role> tag. All attributes are shared automatically. In our case method C<upper_name> and attribute C<name> are provided by role.
-
-Let's separate C<Person::Human> into 2 different roles;
-
-  package main;
-  use Evo;
-
-  {
-
-    package Person::Human;
-    use Evo '-Comp::Role *; -Loaded';
-    has 'name';
-
-    package Person::LoudHuman;
-    use Evo '-Comp::Role *; -Loaded';
-
-    requires 'name';
-    sub upper_name : Role { uc shift->name }
-
-    package Person;
-    use Evo '-Comp *';
-
-    with ':LoudHuman', ':Human';
-    sub intro { say "My name is ", shift->upper_name }
-
-  };
-
-  my $alex = Person::new(name => 'alex');
-  $alex->intro;
-
-Pay attention to the C<requires>.
-
-=head3 features
-
-=head4 role_gen
-
-Creates generator, very similar to L<Evo::Export/"export_gen">
-
-=head4 role_proxy
-
-  role_proxy 'My::Another', 'My::Another2';
-
-Proxy attributes and methods from one role to another
-
-=head4 role_methods
-
-C<:Role> attribute is preffered
-
-=head4 requires
-
-List method that should be available in component during role installation.
-If you require attribute, describe it before L</"with">. If you have circular dependencies, load all roles in the single L</"with">.
-
-=head4 with
-
-Load role and install all methods and attributes to the component
+Instead of OO inheritance, wich suffers from fragile base class problem, C<Evo::Comp> provides L<Evo::Comp::Role>. This is a perfect choice for code reuse because of it's safety and flexibility. Look at L<Evo::Comp::Role> for more information
 
 =head1 AUTHOR
 
