@@ -78,7 +78,7 @@ Evo::Export
 
 =head1 VERSION
 
-version 0.0177
+version 0.0178
 
 =head1 DESCRIPTION
 
@@ -154,36 +154,6 @@ renamed version of that name
   # import all as is but only deferred will be renamed to "renamed_deferred"
   use Evo '-Promises *, -deferred, deferred:renamed_deferred';
 
-=head1 RUNNING EXAMPLES
-
-!!!Pay attention. Too keep examples inlined, we use "-Loaded", to mark inline packages as loaded. If you got "Can't load..." or "My::Lib exports nothing" or similar error,  don't forget it.
-
-for example: 
-
-  package main;
-  use Evo;
-
-  {
-
-    package My::Lib;
-    use Evo '-Export *; -Loaded';
-
-    BEGIN {
-      export_gen foo => sub ($class) {
-        say "$class requested me";
-        sub {"hello, $class"};
-      };
-    }
-  };
-
-
-  use My::Lib '*';
-  foo();
-
-C<-Loaded> is neccessary for C<use>, and C<BEGIN> for C<export_gen>
-
-In the real code, if you module has it's own file (and perl can read it) you don't need L<Evo::Loaded> or C<BEGIN>
-
 =head1 EXPORTING
 
 Using attribute C<Export>
@@ -194,7 +164,7 @@ Using attribute C<Export>
   {
 
     package My::Lib;
-    use Evo -Loaded;
+    use Evo -Loaded; # don't needed in the real code
     use Evo '-Export *';
 
     sub foo : Export {say 'foo'}
@@ -211,10 +181,6 @@ You can export with another name
   # export as bar
   sub foo : Export(bar) {say 'foo'}
 
-=head3 Features
-
-Pay attention, to explore all feature, you need store packages in the real separate file, C<-Loaded> won't always work. (or wrap them in BEGIN blocks)
-
 =head4 export 'foo';
 
 C<Export> signature is more preffered way, but if you wish
@@ -269,7 +235,9 @@ Export function, that won't be available in the source class
   use My::Lib '*';
   foo();
 
-Very powefull and most excited feature. C<Evo::Export> export generators, that produces subroutines. Consider it as a 3nd dimension in 3d programming
+I<L<Evo::Loaded> and C<BEGIN> are for example only, don't needed in the real code>
+
+Very powefull and most exciting feature. C<Evo::Export> exports generators, that produces subroutines. Consider it as a 3nd dimension in 3d programming
 
 Implementation garanties that one module will get the same (cashed) generated unit (if it'l import twice or import from module that reimport the same thing), but different module will get another one
 
